const Data = {
  "name": "USA",
  "value": 25,
  "type": "black",
  "level": "red",
  "children": [
    {
      "name": "Texas",
      "value": 18,
      "type": "black",
      "level": "blue",
       "children": [
        {
          "name": "Austin",
          "value": 8,
          "type": "black",
          "level": "yellow"
        },
        {
          "name": "Dallas",
          "value": 8,
          "type": "black",
          "level": "lightgreen"
        },
         {
          "name": "Huston",
          "value": 8,
          "type": "black",
          "level": "yellow"
        }
      ]
    },
    
    {
      "name": "Maryland",
      "value": 18,
      "type": "white",
      "level": "green",
      "children":[
        {
          "name": "Baltimore",
      		"value": 8,
      		"type": "black",
      		"level": "yellow"
        },
        {
          "name": "Fredrick",
      		"value": 8,
      		"type": "black",
      		"level": "yellow"
        },
        {
          "name": "Silver Springs",
      		"value": 8,
      		"type": "black",
      		"level": "yellow"
        }
        ]
    }
  ]
};

//Define margin , width and height of the tree
const margin = {top: 30, right: 200, bottom: 40, left: 100},
      width  = 1060 - margin.left - margin.right,
      height = 600 - margin.top - margin.bottom;

//Declares a tree with size
const tree = d3.tree().size([height, width]);

//  assigning data to a hierarchy using relationships.
let nodes = d3.hierarchy(Data, node => node.children);

// maps the node data to the tree
nodes = tree(nodes);

// append the svg to the body
const svg = d3.select("body").append("svg")
        .attr("width", width + margin.left + margin.right)
        .attr("height", height + margin.top + margin.bottom),
      g = svg.append("g")//appends group
        .attr("transform",
            "translate(" + margin.left + "," + margin.top + ")");

// adding links between the nodes
const link = g.selectAll(".link")
    .data( nodes.descendants().slice(1))
  .enter().append("path")
    .attr("class", "link")
    .style("stroke", d => d.data.level)
    .attr("d", d => {
       return "M" + d.y + "," + d.x
         + "C" + (d.y + d.parent.y) / 2 + "," + d.x
         + " " + (d.y + d.parent.y) / 2 + "," + d.parent.x
         + " " + d.parent.y + "," + d.parent.x;
       });

// adding each node as a group
const node = g.selectAll(".node")
    .data(nodes.descendants())
    .enter().append("g")
    .attr("class", d => "node" + (d.children ? " node--internal" : " node--leaf"))
    .attr("transform", d => "translate(" + d.y + "," + d.x + ")");

// adds the circle to the node
node.append("circle")
  .attr("r", d => d.data.value)
  .style("stroke", d => d.data.type)
  .style("fill", d => d.data.level);
  
// appending text to the node
node.append("text")
  .attr("dy", ".35em")
  .attr("x", d => d.children ? (d.data.value + 5) * -1 : d.data.value + 5)
  .attr("y", d => d.children && d.depth !== 0 ? -(d.data.value + 5) : d)
  .style("text-anchor", d => d.children ? "end" : "start")
  .text(d => d.data.name);
    